@@ -11,16 +11,18 @@ from flask_mail import Message
 debug = False
 
 #----------------------------------------------------------------------
-def sendmail(subject, fromaddr, toaddr, html, text='', ccaddr=None ):
+def sendmail(subject, fromaddr, toaddr, html, text='', ccaddr=None, replytoaddr=None):
 #----------------------------------------------------------------------
     '''
     send mail
 
     :param subject: subject of email
     :param fromaddr: from address to use
-    :param toaddr: to address to use, may be list of addresses
+    :param toaddr: to address to use, may be list of addresses or comma separated
     :param html: html to send
     :param text: optional text alternative to send
+    :param ccaddr: optional cc address to use, may be list of addresses or comma separated
+    :param replytoaddr: optional reply_to address to use, may be list of addresses or comma separated
     :returns: response from flask_mail.send
     '''
     current_app.logger.info('sendmail(): from={}, to={}, cc={}, subject="{}"'.format(fromaddr, toaddr, ccaddr, subject))
@@ -30,7 +32,9 @@ def sendmail(subject, fromaddr, toaddr, html, text='', ccaddr=None ):
 
     message = Message(
         sender=fromaddr,
-        recipients=toaddr if isinstance(toaddr, list) else [toaddr],
+        recipients=toaddr if isinstance(toaddr, list) else [a.strip() for a in toaddr.split(',')],
+        cc=ccaddr if not ccaddr or isinstance(ccaddr, list) else [a.strip() for a in ccaddr.split(',')],
+        reply_to=replytoaddr if not replytoaddr or isinstance(replytoaddr, list) else [a.strip() for a in replytoaddr.split(',')],
         subject=subject,
         html=html,
         body=text,
